==> gulp-taskify-0.0.7.tgz: package/lib/createTask.js <==
'use strict';

/**
 * @description
 * Lorem ipsum dolor sit amet
 *
 * @param {string} taskPath
 * Lorem ipsum dolor sit amet
 *
 * @param {array} args
 * Lorem ipsum dolor sit amet
 *
 * @returns {array} tasks
 * Lorem ipsum dolor sit amet
 */
module.exports = function createTask (taskPath, args) {

    var
        //
        fs   = require('fs'),
        path = require('path'),

        //
        scaffoldTaskObj = require('./scaffoldTaskObj.js'),

        //
        cwd = process.cwd(),

        //
        subtasks,
        subtasksPath,

        //
        taskNameSeperator = '--',

        //
        taskObj;

    //
    try {
        subtasksPath = path.normalize(taskPath + '/subtasks');
    } catch (err) {
        throw err;
    }

    //
    taskPath     = path.join(cwd, taskPath);
    subtasksPath = path.join(cwd, subtasksPath);

    //
    try {
        taskObj = scaffoldTaskObj(taskPath, args);
    } catch (err) {
        throw err;
    }

    //
    try {
        subtasks = fs.lstatSync(subtasksPath);
    } catch (err) {}

    //
    if (!subtasks || !subtasks.isDirectory()) {
        taskObj.subtasks = [];
        return taskObj;
    }

    //
    try {
        subtasks = fs.readdirSync(subtasksPath);
    } catch (err) {
        throw err;
    }

    //
    if (!subtasks.length) {
        throw new Error('Subtask folder found but no subtasks were found');
    }

    //
    taskObj.subtasks = subtasks.map(function mapSubtasksFn (subtaskPath) {

        var
            //
            subtaskObj;

        //
        try {
            subtaskPath = path.join(subtasksPath, subtaskPath);
        } catch (err) {
            throw err;
        }

        //
        try {
            subtaskObj = scaffoldTaskObj(subtaskPath, args);
        } catch (err) {
            throw err;
        }

        //
        subtaskObj.alias = subtaskObj.alias.map(function (alias) {
            return taskObj.name + taskNameSeperator + alias;
        });

        //
        subtaskObj.name = taskObj.name + taskNameSeperator + subtaskObj.name;

        //
        return subtaskObj;

    });

    //
    return taskObj;

};

==> gulp-taskify-0.0.9.tgz: package/lib/createTask.js <==
'use strict';

/**
 * @description
 * Lorem ipsum dolor sit amet
 *
 * @requires fs
 * @requires path
 * @requires ./scaffoldTaskObj
 *
 * @param {object} options
 * Lorem ipsum dolor sit amet
 *
 * @param {string} taskPath
 * Lorem ipsum dolor sit amet
 *
 * @param {array} args
 * Lorem ipsum dolor sit amet
 *
 * @returns {array} tasks
 * Lorem ipsum dolor sit amet
 */
module.exports = function createTask (options, taskPath, args) {

    var
        //
        fs   = require('fs'),
        path = require('path'),

        //
        scaffoldTaskObj = require('./scaffoldTaskObj.js'),

        //
        subtasks,
        subtasksPath,

        //
        canSubtask,

        //
        taskObj;

    //
    try {
        taskObj = scaffoldTaskObj(taskPath, args);
    } catch (err) {
        throw err;
    }

    //
    try {
        canSubtask = fs.lstatSync(taskPath);
    } catch (err) {
        canSubtask = false;
    }

    //
    if (!canSubtask || !canSubtask.isDirectory()) {
        taskObj.subtasks = [];
        return taskObj;
    }

    //
    try {
        subtasksPath = path.normalize(taskPath + '/' + options.subtasks);
    } catch (err) {
        throw err;
    }

    //
    try {
        subtasks = fs.lstatSync(subtasksPath);
    } catch (err) {
        subtasks = false;
    }

    //
    if (!subtasks || !subtasks.isDirectory()) {
        taskObj.subtasks = [];
        return taskObj;
    }

    //
    try {
        subtasks = fs.readdirSync(subtasksPath);
    } catch (err) {
        throw err;
    }

    //
    if (!subtasks.length) {
        throw new Error('Subtask folder found but no subtasks were found');
    }

    //
    taskObj.subtasks = subtasks.map(function (subtaskPath) {

        var
            //
            subtaskObj;

        //
        try {
            subtaskPath = path.join(subtasksPath, subtaskPath);
        } catch (err) {
            throw err;
        }

        //
        try {
            subtaskObj = scaffoldTaskObj(subtaskPath, args);
        } catch (err) {
            throw err;
        }

        //
        subtaskObj.alias = subtaskObj.alias.map(function (alias) {

            //
            alias = options.seperator(taskObj.name, alias);

            //
            if (typeof alias !== 'string') {
                throw new Error();
            }

            //
            return alias;

        });

        //
        subtaskObj.name = options.seperator(taskObj.name, subtaskObj.name);

        //
        return subtaskObj;

    });

    //
    return taskObj;

};
